Learn R Programming

OptimalGoldstandardDesigns (version 1.0.1)

calc_conditional_local_rejection_probs: Calculate the (local) conditional type I errors of both hypothesis given both interim test statistics.

Description

Calculate the (local) conditional type I errors of both hypothesis given both interim test statistics.

Usage

calc_conditional_local_rejection_probs(Z_TP1, Z_TC1, D, mu_vec = D$mu_vec$H0)

Value

named numeric vector with both conditional type I errors.

Arguments

Z_TP1

First stage Z-test statistic of the superiority test of treatment over placebo.

Z_TC1

First stage Z-test statistic of the non-inferiority test of treatment to the active control.

D

list containing all parameters of a the trial design.

mu_vec

vector of means of the test statistic c(Z_TP1, Z_TP2, Z_TC1, Z_TC1).