Learn R Programming

OptimalGoldstandardDesigns (version 1.0.1)

calc_local_alphas: Helper function to calculate the local type I error rates of a Design

Description

Helper function to calculate the local type I error rates of a Design

Usage

calc_local_alphas(D)

Arguments

D

list containing all parameters of a the trial design.