Helper function to calculate the local rejection boundaries of group sequential testing procedure associated with the hypothesis belong to the groups argument
calc_local_rejection_boundaries(groups = "TP", D)string describing the pair of groups. Either "TP" or "TC".
list containing all parameters of a the trial design.