calc_mu_vec: Helper function to calculate expected value of normal test statistic vector c(Z_TP1, Z_TP2, Z_TC1, Z_TP2)
under the null and alternative hypothesis given nT1, gamma and mu.
Description
Helper function to calculate expected value of normal test statistic vector c(Z_TP1, Z_TP2, Z_TC1, Z_TP2)
under the null and alternative hypothesis given nT1, gamma and mu.
Usage
calc_mu_vec(D)
Arguments
D
list containing all parameters of a the trial design.