calc_nT1_wrt_bTC2e: Helper function to calculate the required sample size (of the stage 1 treatment group)
to achieve the target power given the bTC2e
Description
Helper function to calculate the required sample size (of the stage 1 treatment group)
to achieve the target power given the bTC2e
Usage
calc_nT1_wrt_bTC2e(bTC2e, D)
Arguments
- bTC2e
second stage critical value for the TC testing problem.
- D
list containing all parameters of a the trial design.