calc_prob_reject_both: Helper function to calculate the probability to reject both hypotheses
given the mean of the normal test statistic vector c(Z_TP1, Z_TP2, Z_TC1, Z_TC2).
Description
Helper function to calculate the probability to reject both hypotheses
given the mean of the normal test statistic vector c(Z_TP1, Z_TP2, Z_TC1, Z_TC2).
Usage
calc_prob_reject_both(mu_vec, D)
Arguments
- mu_vec
vector of means of the test statistic c(Z_TP1, Z_TP2, Z_TC1, Z_TC1).
- D
list containing all parameters of a the trial design.