Calculate the (local) conditional type I errors of both hypothesis given both interim test statistics.
calc_conditional_local_rejection_probs(Z_TP1, Z_TC1, D, mu_vec = D$mu_vec$H0)named numeric vector with both conditional type I errors.
First stage Z-test statistic of the superiority test of treatment over placebo.
First stage Z-test statistic of the non-inferiority test of treatment to the active control.
list containing all parameters of a the trial design.
vector of means of the test statistic c(Z_TP1, Z_TP2, Z_TC1, Z_TC1).