calc_mu_wo_nT1: Helper function to calculate expected value of normal test statistic vector c(Z_TP1, Z_TP2, Z_TC1, Z_TP2)
under the null and alternative hypothesis given nT1=1, gamma and mu.
Description
This quantity is helpful when solving for the smallest n which fulfills a certain power constraint.
Usage
calc_mu_wo_nT1(D)
Arguments
D
list containing all parameters of a the trial design.